@@ -25,12 +25,12 @@ g.dotorcomma = function(inputfile, dformat, mon, desiredtz = "", loadGENEActiv =
     # Note: I have added the below lines because some ActiGraph files start with a
     # lot of zeros, which makes it impossible to detect decimal separator
     # "." will then be the default, which is not correct for "," systems.
-    while (skiprows < 1000000) { #foundnonzero == FALSE & 
+    while (skiprows < 1000000) { #foundnonzero == FALSE &
       deci = as.matrix(read.csv(inputfile, skip = skiprows, nrow = 10))
       skiprows = skiprows + 10000
       if (length(unlist(strsplit(as.character(deci[2,2]), ","))) > 1) {
         decn = ","
-        break() 
+        break()
       }
       numtemp = as.numeric(deci[2,2])
       if (is.na(numtemp) == FALSE) {
@@ -40,20 +40,12 @@ g.dotorcomma = function(inputfile, dformat, mon, desiredtz = "", loadGENEActiv =
     if (!exists("deci")) stop("Problem with reading .csv file in GGIR function dotorcomma")
     if (is.na(suppressWarnings(as.numeric(deci[2,2]))) == T & decn == ".") decn = ","
   } else if (dformat == 1) {
-    if (mon == 1) {
-      # GENEA values are stroed in g without decimal place.
-      try(expr = {deci = GGIRread::readGenea(inputfile,0,2)}, silent = TRUE)
-      if (is.na(suppressWarnings(as.numeric(deci$rawxyz[2,2]))) == T) decn = ","
-    } else if (mon == 2 ) {
+    if (mon == 2 ) {
       try(expr = {deci = GGIRread::readGENEActiv(filename = inputfile,
                                                  start = 1, end = 3)}, silent = TRUE)
       if (!exists("deci")) stop("Problem with reading .bin file in GGIR function dotorcomma")
       if (is.na(as.numeric(deci$data.out[2, 2])) == T & decn == ".") decn = ","
     }
-  } else if (dformat == 3) {
-    try(expr = {deci = g.wavread(wavfile = inputfile,start = 1, end = 10)}, silent = TRUE)
-    if (!exists("deci")) stop("Problem with reading .wav file in GGIR function dotorcomma")
-    if (is.na(suppressWarnings(as.numeric(deci$rawxyz[2,2]))) == T & decn == ".") decn = ","
   } else if (dformat == 4) {
     try(expr = {deci = GGIRread::readAxivity(filename = inputfile,start = 1, end = 10, desiredtz = desiredtz,
                                interpolationType = 1)$data},silent = TRUE)
@@ -64,7 +56,7 @@ g.dotorcomma = function(inputfile, dformat, mon, desiredtz = "", loadGENEActiv =
       inputfile = gsub(pattern = "[.]GT3X", replacement = "[.]gt3x", x = inputfile)
     }
     try(expr = {deci = as.data.frame(read.gt3x::read.gt3x(path = inputfile,
-                                                       batch_begin = 1, batch_end = 10, 
+                                                       batch_begin = 1, batch_end = 10,
                                                        asDataFrame = TRUE))}, silent = TRUE)
     if (!exists("deci")) stop("Problem with reading .gt3x file in GGIR function dotorcomma")
     if (is.na(suppressWarnings(as.numeric(deci[2,2]))) == T & decn == ".") decn = ","
