@@ -1,14 +1,14 @@
 g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
-                     params_general = c(), daylimit = FALSE, 
+                     params_general = c(), params_cleaning = c(), daylimit = FALSE,
                      offset = c(0, 0, 0), scale = c(1, 1, 1), tempoffset = c(0, 0, 0),
-                     meantempcal = c(), myfun = c(), ...) {
+                     meantempcal = c(), myfun = c(), verbose = TRUE, ...) {
   
   #get input variables
   input = list(...)
-  expectedArgs = c("datafile", "params_metrics", 
+  expectedArgs = c("datafile", "params_metrics",
                    "params_rawdata", "params_general",
-                   "daylimit", "offset", 
-                   "scale", "tempoffset", "meantempcal", 
+                   "daylimit", "offset",
+                   "scale", "tempoffset", "meantempcal",
                    "myfun", "outputdir", "outputfolder")
   if (any(names(input) %in% expectedArgs == FALSE) |
       any(!unlist(lapply(expectedArgs, FUN = exists)))) {
@@ -18,7 +18,8 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
     params = extract_params(params_metrics = params_metrics,
                             params_rawdata = params_rawdata,
                             params_general = params_general,
-                            input = input) # load default parameters
+                            input = input,
+                            params2check = c("metrics", "rawdata", "general")) # load default parameters
     params_metrics = params$params_metrics
     params_rawdata = params$params_rawdata
     params_general = params$params_general
@@ -52,7 +53,7 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
                           do.dev_roll_med_acc_x = params_metrics[["do.dev_roll_med_acc_x"]],
                           do.dev_roll_med_acc_y = params_metrics[["do.dev_roll_med_acc_y"]],
                           do.dev_roll_med_acc_z = params_metrics[["do.dev_roll_med_acc_z"]],
-                          do.enmoa = params_metrics[["do.enmoa"]], 
+                          do.enmoa = params_metrics[["do.enmoa"]],
                           do.lfen = params_metrics[["do.lfen"]],
                           do.lfx = params_metrics[["do.lfx"]],
                           do.lfy = params_metrics[["do.lfy"]],
@@ -78,14 +79,14 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
                    params_metrics[["do.hfen"]], params_metrics[["do.hfenplus"]],
                    params_metrics[["do.mad"]], params_metrics[["do.anglex"]],
                    params_metrics[["do.angley"]], params_metrics[["do.anglez"]],
-                   params_metrics[["do.roll_med_acc_x"]], params_metrics[["do.roll_med_acc_y"]], 
+                   params_metrics[["do.roll_med_acc_x"]], params_metrics[["do.roll_med_acc_y"]],
                    params_metrics[["do.roll_med_acc_z"]],
-                   params_metrics[["do.dev_roll_med_acc_x"]], params_metrics[["do.dev_roll_med_acc_y"]], 
+                   params_metrics[["do.dev_roll_med_acc_x"]], params_metrics[["do.dev_roll_med_acc_y"]],
                    params_metrics[["do.dev_roll_med_acc_z"]],
                    params_metrics[["do.enmoa"]], params_metrics[["do.lfen"]],
-                   params_metrics[["do.lfx"]], params_metrics[["do.lfy"]], 
-                   params_metrics[["do.lfz"]],  params_metrics[["do.hfx"]], 
-                   params_metrics[["do.hfy"]], params_metrics[["do.hfz"]], 
+                   params_metrics[["do.lfx"]], params_metrics[["do.lfy"]],
+                   params_metrics[["do.lfz"]],  params_metrics[["do.hfx"]],
+                   params_metrics[["do.hfy"]], params_metrics[["do.hfz"]],
                    params_metrics[["do.bfx"]], params_metrics[["do.bfy"]],
                    params_metrics[["do.bfz"]],
                    params_metrics[["do.zcx"]], params_metrics[["do.zcy"]],
@@ -99,7 +100,7 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
   }
   
   if (length(nmetrics) == 0) {
-    cat("\nWARNING: No metrics selected\n")
+    if (verbose == TRUE) cat("\nWARNING: No metrics selected\n")
   }
   filename = unlist(strsplit(as.character(datafile),"/"))
   filename = filename[length(filename)]
@@ -107,15 +108,19 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
   ws3 = params_general[["windowsizes"]][1]; ws2 = params_general[["windowsizes"]][2]; ws = params_general[["windowsizes"]][3]  #window sizes
   if ((ws2/60) != round(ws2/60)) {
     ws2 = as.numeric(60 * ceiling(ws2/60))
-    cat("\nWARNING: The long windowsize needs to be a multitude of 1 minute periods. The\n")
-    cat(paste0("\nlong windowsize has now been automatically adjusted to: ", ws2, " seconds in order to meet this criteria.\n"))
+    if (verbose == TRUE) {
+      cat("\nWARNING: The long windowsize needs to be a multitude of 1 minute periods. The\n")
+      cat(paste0("\nlong windowsize has now been automatically adjusted to: ", ws2, " seconds in order to meet this criteria.\n"))
+    }
   }
   if ((ws2/ws3) != round(ws2/ws3)) {
     def = c(1,5,10,15,20,30,60)
     def2 = abs(def - ws3)
     ws3 = as.numeric(def[which(def2 == min(def2))])
-    cat("\nWARNING: The long windowsize needs to be a multitude of short windowsize. The \n")
-    cat(paste0("\nshort windowsize has now been automatically adjusted to: ", ws3, " seconds in order to meet this criteria.\n"))
+    if (verbose == TRUE) {
+      cat("\nWARNING: The long windowsize needs to be a multitude of short windowsize. The \n")
+      cat(paste0("\nshort windowsize has now been automatically adjusted to: ", ws3, " seconds in order to meet this criteria.\n"))
+    }
   }
   params_general[["windowsizes"]] = c(ws3,ws2,ws)
   data = PreviousEndPage = PreviousStartPage = starttime = wday = weekdays = wdayname = c()
@@ -196,6 +201,7 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
   } else if (mon == 2 | (mon == 4 & dformat == 4)  | mon == 5 | (mon == 0 & length(params_rawdata[["rmc.col.temp"]]) > 0)) {
     temp.available = TRUE
   }
+  QClog = NULL
   if (temp.available == FALSE) {
     metalong = matrix(" ", ((nev/(sf*ws2)) + 100), 4) #generating output matrix for 15 minutes summaries
   } else if (temp.available == TRUE & mon != 5) {
@@ -209,11 +215,14 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
   sforiginal = sf
   while (LD > 1) {
     P = c()
-    if (i  == 1) {
-      cat(paste0("\nLoading chunk: ", i))
-    } else {
-      cat(paste0(" ", i))
+    if (verbose == TRUE) {
+      if (i  == 1) {
+        cat(paste0("\nLoading chunk: ", i))
+      } else {
+        cat(paste0(" ", i))
+      }
     }
+    
     options(warn = -1) #turn off warnings (code complains about unequal rowlengths
     
     if (!exists("PreviousLastValue")) PreviousLastValue = c(0, 0, 1)
@@ -225,7 +234,7 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
                             PreviousLastValue = PreviousLastValue,
                             PreviousLastTime = PreviousLastTime,
                             params_rawdata = params_rawdata, params_general = params_general)
-    if ("PreviousLastValue" %in% names(accread$P)) { # output when reading ad-hoc csv 
+    if ("PreviousLastValue" %in% names(accread$P)) { # output when reading ad-hoc csv
       P = accread$P[1:2]
       PreviousLastValue = accread$P$PreviousLastValue
       PreviousLastTime = accread$P$PreviousLastTime
@@ -271,9 +280,9 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
           }
           if (!exists("PreviousLastValue")) PreviousLastValue = c(0, 0, 1)
           if (!exists("PreviousLastTime")) PreviousLastTime = NULL
-          P = g.imputeTimegaps(P, xyzCol = xyzCol, timeCol = timeCol, sf = sf, k = 0.25, 
+          P = g.imputeTimegaps(P, xyzCol = xyzCol, timeCol = timeCol, sf = sf, k = 0.25,
                                PreviousLastValue = PreviousLastValue,
-                               PreviousLastTime = PreviousLastTime, 
+                               PreviousLastTime = PreviousLastTime,
                                epochsize = c(ws3, ws2))
           PreviousLastValue = as.numeric(P[nrow(P), xyzCol])
           if (is.null(timeCol)) PreviousLastTime = NULL else PreviousLastTime = as.POSIXct(P[nrow(P), timeCol])
@@ -286,13 +295,14 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
           # GGIR now ignores the AX6 gyroscope signals until added value has robustly been demonstrated
           data = P$data[,-c(2:4)]
           P$data = P$data[1:min(100,nrow(P$data)),-c(2:4)] # trim object, because rest of data is not needed anymore
-          gyro_available = FALSE 
+          gyro_available = FALSE
           # If we ever want to use gyroscope data then
           # comment out this if statement and set gyro_available = TRUE
         } else {
           data = P$data
           P$data = P$data[1:min(100,nrow(P$data)),] # trim object, because rest of data is not needed anymore
         }
+        QClog = rbind(QClog, P$QClog)
       } else if (dformat == 5) { # ad-hoc csv
         data = P$data
       } else if (mon == 5) { #movisense
@@ -301,9 +311,9 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
         if (params_rawdata[["imputeTimegaps"]] == TRUE) {
           if (!exists("PreviousLastValue")) PreviousLastValue = c(0, 0, 1)
           if (!exists("PreviousLastTime")) PreviousLastTime = NULL
-          P = g.imputeTimegaps(P, xyzCol = c("X", "Y", "Z"), timeCol = "time", sf = sf, k = 0.25, 
+          P = g.imputeTimegaps(P, xyzCol = c("X", "Y", "Z"), timeCol = "time", sf = sf, k = 0.25,
                                PreviousLastValue = PreviousLastValue,
-                               PreviousLastTime = PreviousLastTime, 
+                               PreviousLastTime = PreviousLastTime,
                                epochsize = c(ws3, ws2))
           PreviousLastValue = as.numeric(P[nrow(P), c("X", "Y", "Z")])
           PreviousLastTime = as.POSIXct(P[nrow(P), "time"])
@@ -331,7 +341,7 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
         data = suppressWarnings(rbind(S,data)) # suppress warnings about string as factor
       }
       SWMT = get_starttime_weekday_meantemp_truncdata(temp.available, mon, dformat,
-                                                      data, 
+                                                      data,
                                                       P, header, desiredtz = params_general[["desiredtz"]],
                                                       sf, i, datafile,  ws2,
                                                       starttime, wday, weekdays, wdayname, configtz = params_general[["configtz"]])
@@ -412,14 +422,16 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
           }
           temperature = as.numeric(data[, temperaturecolumn])
         }
+
         # Initialization of variables
-        if (mon == 1) {
+        data_scaled = FALSE
+        if (mon == 1 | (mon == 3 & dformat == 6) | ( mon == 4 & dformat == 3)) {
+          # Genea bin, Actigraph gt3x, Axivity wav
           data = data[, 1:3]
           data[, 1:3] = scale(data[, 1:3], center = -offset, scale = 1/scale) #rescale data
-        } else if (mon == 4 & dformat == 3) {
-          data = data[, 1:3]
-          data[, 1:3] = scale(data[, 1:3],center = -offset, scale = 1/scale) #rescale data
+          data_scaled = TRUE
         } else if (mon == 4 & (dformat == 4 |  dformat == 2)) {
+          # Axivity cwa or csv
           extraction_succeeded = FALSE
           if (gyro_available == TRUE) {
             data[,5:7] = scale(data[,5:7],center = -offset, scale = 1/scale) #rescale data
@@ -430,7 +442,9 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
             data[, 2:4] = scale(data[, 2:4],center = -offset, scale = 1/scale) #rescale data
             data = data[,2:4]
           }
+          data_scaled = TRUE
         } else if (mon == 2 & dformat == 1) {
+          # GENEActiv bin
           yy = as.matrix(cbind(as.numeric(data[,temperaturecolumn]),
                                as.numeric(data[,temperaturecolumn]),
                                as.numeric(data[,temperaturecolumn])))
@@ -438,13 +452,17 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
           data[,1:3] = scale(as.matrix(data[,1:3]),center = -offset, scale = 1/scale) +
             scale(yy, center = rep(meantemp,3), scale = 1/tempoffset)  #rescale data
           rm(yy); gc()
+          data_scaled = TRUE
         } else if (mon == 5) {
+          # Movisense
           yy = as.matrix(cbind(as.numeric(data[,4]),as.numeric(data[,4]),as.numeric(data[,4])))
           data = data[,1:3]
           data[,1:3] = scale(as.matrix(data[,1:3]),center = -offset, scale = 1/scale) +
             scale(yy, center = rep(meantemp,3), scale = 1/tempoffset)  #rescale data
           rm(yy); gc()
+          data_scaled = TRUE
         } else if ((dformat == 2 | dformat == 5) & (mon != 4)) {
+          # Any brand that is not Axivity with csv or Movisense format data
           if (mon == 2 | (mon == 0 & use.temp == TRUE)) {
             tempcolumnvalues = as.numeric(as.character(data[,temperaturecolumn]))
             yy = as.matrix(cbind(tempcolumnvalues, tempcolumnvalues, tempcolumnvalues))
@@ -473,6 +491,11 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
               scale(yy, center = rep(meantempcal,3), scale = 1/tempoffset)  #rescale data
             rm(yy); gc()
           }
+          data_scaled = TRUE
+        }
+        if (data_scaled == FALSE) {
+          warning(paste0("\nAutocalibration was not applied, this should",
+                         "not happen please contact GGIR maintainers"))
         }
         suppressWarnings(storage.mode(data) <- "numeric")
         ## resample experiment to see whehter processing time can be much improved if data is resampled
@@ -481,7 +504,7 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
         # data[,1], data[,2], data[,3], starttime, (temperature, light)
         
         EN = sqrt(data[,1]^2 + data[,2]^2 + data[,3]^2) # Do not delete Used for long epoch calculation
-        accmetrics = g.applymetrics(data = data, 
+        accmetrics = g.applymetrics(data = data,
                                     sf = sf, ws3 = ws3,
                                     metrics2do = metrics2do,
                                     n = params_metrics[["n"]],
@@ -526,7 +549,7 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
           metashort = rbind(metashort,extension)
           extension2 = matrix(" ", ((3600/ws2) * 24)  + (totalgap * (ws2/ws3)), ncol(metalong)) #add another day to metashort once you reach the end of it
           metalong = rbind(metalong, extension2)
-          cat("\nvariable metashort extended\n")
+          if (verbose == TRUE) cat("\nvariable metashort extended\n")
         }
         col_msi = 2
         # Add metric time series to metashort object
@@ -568,59 +591,15 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
         blocksize = BlocksizeNew$blocksize
         ##==================================================
         # MODULE 2 - non-wear time & clipping
-        window2 = ws2 * sf #window size in samples
-        window = ws * sf #window size in samples
-        nmin = floor(LD/(window2)) #nmin = minimum number of windows that fit in this block of data
-        CW = NW = matrix(0,nmin,3) #CW is clipping, NW is non-wear
-        TS1W = TS2W = TS3W = TS4W = TS5W = TS6W = TS7W = CWav = NWav = matrix(0, nmin, 1)
-        crit = ((window/window2)/2) + 1
-        for (h in 1:nmin) { #number of windows
-          cliphoc1 = (((h - 1) * window2) + window2 * 0.5 ) - window2 * 0.5 #does not use "window"
-          cliphoc2 = (((h - 1) * window2) + window2 * 0.5 ) + window2 * 0.5
-          if (h <= crit) {
-            hoc1 = 1
-            hoc2 = window
-          } else if (h >= (nmin - crit)) {
-            hoc1 = (nmin - crit)*window2
-            hoc2 = nmin*window2 #end of data
-          } else if (h > crit & h < (nmin - crit)) {
-            hoc1 = (((h - 1) * window2) + window2 * 0.5 ) - window * 0.5
-            hoc2 = (((h - 1) * window2) + window2 * 0.5 ) + window * 0.5
-          }
-          if (length(params_rawdata[["rmc.col.wear"]]) > 0) {
-            wearTable = table(wearcol[(1 + hoc1):hoc2], useNA = FALSE)
-            NWav[h,1] = as.logical(tail(names(sort(wearTable)), 1)) * 3 # times 3 to simulate heuristic approach
-          }
-          for (jj in  1:3) {
-            #hoc1 & hoc2 = edges of windows
-            #window is bigger& window2 is smaller one
-            sdwacc = sd(as.numeric(data[(1 + hoc1):hoc2,jj]), na.rm = TRUE)
-            maxwacc = max(as.numeric(data[(1 + hoc1):hoc2,jj]), na.rm = TRUE)
-            minwacc = min(as.numeric(data[(1 + hoc1):hoc2,jj]), na.rm = TRUE)
-            CW[h,jj] = length(which(abs(as.numeric(data[(1 + cliphoc1):cliphoc2,jj])) > clipthres))
-            if (length(which(abs(as.numeric(data[(1 + cliphoc1):cliphoc2,jj])) > clipthres*1.5)) > 0) {
-              CW[h,jj] = window2 # If there is a a value that is more than 150% the dynamic range then ignore entire block.
-            }
-            absrange = abs(maxwacc - minwacc)
-            if (is.numeric(absrange) == TRUE & is.numeric(sdwacc) == TRUE & is.na(sdwacc) == FALSE) {
-              if (sdwacc < sdcriter) {
-                if (absrange < racriter) {
-                  NW[h,jj] = 1
-                }
-              }
-            } else {
-              NW[h,jj] = 1 # if sdwacc, maxwacc, or minwacc could not be derived then label as non-wear
-            }
-          }
-          CW = CW / (window2) #changed 30-1-2012, was window*sf
-          if (length(params_rawdata[["rmc.col.wear"]]) == 0) {
-            NWav[h,1] = (NW[h,1] + NW[h,2] + NW[h,3]) #indicator of non-wear
-          }
-          CWav[h,1] = max(c(CW[h,1],CW[h,2],CW[h,3])) #indicator of clipping
-        }
+        NWCW = detect_nonwear_clipping(data = data, windowsizes = c(ws3, ws2, ws), sf = sfold,
+                                       clipthres = clipthres, sdcriter = sdcriter, racriter = racriter,
+                                       nonwear_approach = params_cleaning[["nonwear_approach"]],
+                                       params_rawdata = params_rawdata)
+        NWav = NWCW$NWav; CWav = NWCW$CWav; nmin = NWCW$nmin
+        # metalong
         col_mli = 2
-        metalong[count2:((count2 - 1) + nrow(NWav)),col_mli] = NWav; col_mli = col_mli + 1
-        metalong[(count2):((count2 - 1) + nrow(NWav)),col_mli] = CWav; col_mli = col_mli + 1
+        metalong[count2:((count2 - 1) + length(NWav)),col_mli] = NWav; col_mli = col_mli + 1
+        metalong[(count2):((count2 - 1) + length(NWav)),col_mli] = CWav; col_mli = col_mli + 1
         if (mon == 2 | (mon == 4 & dformat == 4) | mon == 5) { #going from sample to ws2
           if (mon == 2 | (mon == 4 & dformat == 4)) {
             #light (running mean)
@@ -651,24 +630,24 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
         ENb = diff(ENc[round(select)]) / abs(diff(round(select)))
         rm(ENc, EN); gc()
         if (mon == 2 | (mon == 4 & dformat == 4)) {
-          metalong[(count2):((count2 - 1) + nrow(NWav)), col_mli] = round(lightmean, digits = n_decimal_places)
+          metalong[(count2):((count2 - 1) + length(NWav)), col_mli] = round(lightmean, digits = n_decimal_places)
           col_mli = col_mli + 1
-          metalong[(count2):((count2 - 1) + nrow(NWav)), col_mli] = round(lightmax, digits = n_decimal_places)
+          metalong[(count2):((count2 - 1) + length(NWav)), col_mli] = round(lightmax, digits = n_decimal_places)
           col_mli = col_mli + 1
-          metalong[(count2):((count2 - 1) + nrow(NWav)), col_mli] = round(temperatureb, digits = n_decimal_places)
+          metalong[(count2):((count2 - 1) + length(NWav)), col_mli] = round(temperatureb, digits = n_decimal_places)
           col_mli = col_mli + 1
         } else if (mon == 5) {
-          metalong[(count2):((count2 - 1) + nrow(NWav)), col_mli] = round(temperatureb, digits = n_decimal_places)
+          metalong[(count2):((count2 - 1) + length(NWav)), col_mli] = round(temperatureb, digits = n_decimal_places)
           col_mli = col_mli + 1
         }
-        metalong[(count2):((count2 - 1) + nrow(NWav)), col_mli] = round(ENb, digits = n_decimal_places)
+        metalong[(count2):((count2 - 1) + length(NWav)), col_mli] = round(ENb, digits = n_decimal_places)
         if (exists("remaining_epochs")) {
           # Impute long gaps at epoch levels, because imputing them at raw level would
           # be too memory hungry
           impute_at_epoch_level = function(gapsize, timeseries, gap_index, metnames) {
             # gap_index: where do gaps occur (epoch indexing)
             # gap_size: how long is gap (epoch numbers)
-            if (any(duplicated(gap_index))) { 
+            if (any(duplicated(gap_index))) {
               # When 2 gap_index are within the same epoch (either short or long)
               # we would have a duplicated gap_index here, then combine information
               dup_index_tmp = which(duplicated(gap_index))
@@ -679,14 +658,14 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
                 delete = to_combine[-1] # leave only the first index and remove duplicates
                 gap_index = gap_index[-delete] # remove from gap index
                 gapsize[to_combine[1]] = sum(gapsize[to_combine]) - (length_to_combine - 1) # minus 1 because it was summed 1 to each gapsize (which is +2 when it is duplicated) in the function call
-                gapsize = gapsize[-delete] 
+                gapsize = gapsize[-delete]
               }
             }
             if ("nonwearscore" %in% metnames) {
               timeseries[gap_index, which(metnames == "nonwearscore")]  = 3
             } else {
               # set all features to zero except time and angle feature
-              timeseries[gap_index, grep(pattern = "time|angle", 
+              timeseries[gap_index, grep(pattern = "time|angle",
                                          x = metnames, invert = TRUE, value = FALSE)] = 0
               # set EN to 1 if it is available
               if ("EN" %in% metnames) timeseries[gap_index, which(metnames == "EN")] = 1
@@ -706,8 +685,8 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
                                              timeseries = metalong,
                                              gap_index = floor(gaps_to_fill / (ws2 * sfold)) + count2, # Using floor so that the gap is filled in the epoch in which it is occurring
                                              metnames = metricnames_long)
-            
             # metashort
+            # added epoch-level nonwear to metashort to get it imputed, then remove it
             metashort = impute_at_epoch_level(gapsize = remaining_epochs[gaps_to_fill], # gapsize in epochs
                                               timeseries = metashort,
                                               gap_index = floor(gaps_to_fill / (ws3 * sfold)) + count, # Using floor so that the gap is filled in the epoch in which it is occurring
@@ -733,7 +712,7 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
     if (ceiling(daylimit) != FALSE) {
       if (i == ceiling(daylimit)) { #to speed up testing only read first 'i' blocks of data
         LD = 0 #once LD < 1 the analysis stops, so this is a trick to stop it
-        cat(paste0("\nstopped reading data because this analysis is limited to ", ceiling(daylimit), " days\n"))
+        if (verbose == TRUE) cat(paste0("\nstopped reading data because this analysis is limited to ", ceiling(daylimit), " days\n"))
       }
     }
     i = i + 1 #go to next block
@@ -796,5 +775,5 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
   if (length(metashort) == 0 | filedoesnotholdday == TRUE) filetooshort = TRUE
   invisible(list(filecorrupt = filecorrupt, filetooshort = filetooshort, NFilePagesSkipped = NFilePagesSkipped,
                  metalong = metalong, metashort = metashort, wday = wday, wdayname = wdayname,
-                 windowsizes = params_general[["windowsizes"]], bsc_qc = bsc_qc))
-}
\ No newline at end of file
+                 windowsizes = params_general[["windowsizes"]], bsc_qc = bsc_qc, QClog = QClog))
+}
