@@ -234,7 +234,8 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
         C = g.calibrate(datafile,
                         params_rawdata = params_rawdata,
                         params_general = params_general,
-                        params_cleaning = params_cleaning)
+                        params_cleaning = params_cleaning,
+                        verbose = verbose)
       } else {
         C = list(cal.error.end = 0, cal.error.start = 0)
         C$scale = c(1,1,1)
@@ -273,7 +274,7 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
       # three columns respectively named temperature.offset.x, temperature.offset.y, and temperature.offset.z
       # the end-user can generate this document based on calibration analysis done with the same accelerometer device.
       if (length(params_rawdata[["backup.cal.coef"]]) > 0 & check.backup.cal.coef == TRUE) {
-        bcc.data = read.csv(params_rawdata[["backup.cal.coef"]])
+        bcc.data = data.table::fread(params_rawdata[["backup.cal.coef"]], data.table = FALSE)
         if (isTRUE(params_rawdata[["do.cal"]]) & verbose == TRUE) {
           cat("\nRetrieving previously derived calibration coefficients")
         }
@@ -324,12 +325,14 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
                     params_metrics = params_metrics,
                     params_rawdata = params_rawdata,
                     params_general = params_general,
+                    params_cleaning = params_cleaning,
                     daylimit = daylimit,
                     tempoffset = C$tempoffset, scale = C$scale, offset = C$offset,
                     meantempcal = C$meantempcal,
                     outputdir = outputdir,
                     outputfolder = outputfolder,
-                    myfun = myfun)
+                    myfun = myfun,
+                    verbose = verbose)
 
       if (!is.null(params_general[["recordingEndSleepHour"]])) {
         # Identify gap between last timestamp and following midnight
@@ -370,6 +373,7 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
           expand_indices = (NR + 1):(NR + N_short_epochs_expand)
           expand_tsPOSIX = seq(last_ts[2] + ws3, last_ts[2] + (N_short_epochs_expand * ws3), by = ws3)
           M$metashort[expand_indices,] = metashort_expand
+          M$nonwear[expand_indices] = 0
           M$metashort$timestamp[expand_indices] = POSIXtime2iso8601(expand_tsPOSIX, tz = params_general[["desiredtz"]])
           anglecol = grep(pattern = "angle", x = names(metashort_expand), value = FALSE)
           if (length(anglecol) > 0) {
@@ -463,13 +467,16 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
     } else { # development mode, pass on individual function that were sourced by developer
       # pass on functions
       # packages2passon = 'Rcpp'
-      functions2passon = c("g.inspectfile", "g.calibrate","g.getmeta", "g.dotorcomma", "g.applymetrics",
-                           "g.readaccfile", "g.wavread", "g.downsample", "updateBlocksize",
+      functions2passon = c("g.inspectfile", "g.calibrate","g.getmeta", "g.dotorcomma",
+                           "g.applymetrics",
+                           "g.readaccfile", "g.downsample", "updateBlocksize",
                            "g.getstarttime", "POSIXtime2iso8601",
                            "iso8601chartime2POSIX", "datadir2fnames", "read.myacc.csv",
-                           "get_nw_clip_block_params", "get_starttime_weekday_meantemp_truncdata", "ismovisens",
-                           "g.extractheadervars", "g.imputeTimegaps", "extract_params", "load_params",
-                           "check_params")
+                           "get_nw_clip_block_params",
+                           "get_starttime_weekday_meantemp_truncdata", "ismovisens",
+                           "g.extractheadervars", "g.imputeTimegaps", "extract_params",
+                           "load_params",
+                           "check_params", "detect_nonwear_clipping")
       errhand = 'stop'
       # Note: This will not work for cwa files, because those also need Rcpp functions.
       # So, it is probably best to turn off parallel when debugging cwa data.
