@@ -1,5 +1,6 @@
 g.report.part2 = function(metadatadir = c(), f0 = c(), f1 = c(), maxdur = 0,
                           selectdaysfile = c(), store.long = FALSE, do.part2.pdf = TRUE,
+                          sep_reports = ",",
                           verbose = TRUE) {
   ms2.out = "/meta/ms2.out"
   if (file.exists(paste0(metadatadir,ms2.out))) {
@@ -129,6 +130,8 @@ g.report.part2 = function(metadatadir = c(), f0 = c(), f1 = c(), maxdur = 0,
         deviceSerialNumber = "not extracted"
       } else if (I$monc == 5) { #movisense
         deviceSerialNumber = "not extracted"
+      } else if (I$monc == 99) {
+        deviceSerialNumber = "not extracted"
       } else if (I$monc == 0) {
         if (header != "no header") {
           deviceSerialNumber = hvalues[which(hnames == "device_serial_number")]
@@ -153,7 +156,8 @@ g.report.part2 = function(metadatadir = c(), f0 = c(), f1 = c(), maxdur = 0,
       }
       if (length(M$NFilePagesSkipped) == 0) M$NFilePagesSkipped = 0 # to make the code work for historical part1 output.
       
-      QC = data.frame(filename = fnames[i],
+      fname2store = unlist(strsplit(fnames[i], "eta_|[.]RDat"))[2]
+      QC = data.frame(filename = fname2store,
                       file.corrupt = M$filecorrupt,
                       file.too.short = M$filetooshort,
                       use.temperature = C$use.temp,
@@ -168,21 +172,12 @@ g.report.part2 = function(metadatadir = c(), f0 = c(), f1 = c(), maxdur = 0,
                       device.serial.number = deviceSerialNumber,
                       NFilePagesSkipped = M$NFilePagesSkipped, stringsAsFactors = FALSE)
       
-      
-      QC = data.frame(filename = fnames[i],
-                      file.corrupt = M$filecorrupt,
-                      file.too.short = M$filetooshort,
-                      use.temperature = C$use.temp,
-                      scale.x = C$scale[1], scale.y = C$scale[2], scale.z = C$scale[3],
-                      offset.x = C$offset[1], offset.y = C$offset[2], offset.z = C$offset[3],
-                      temperature.offset.x = C$tempoffset[1],  temperature.offset.y = C$tempoffset[2],
-                      temperature.offset.z = C$tempoffset[3],
-                      cal.error.start = C$cal.error.start,
-                      cal.error.end = C$cal.error.end,
-                      n.10sec.windows = C$npoints,
-                      n.hours.considered = C$nhoursused, QCmessage = C$QCmessage, mean.temp = tmean,
-                      device.serial.number = deviceSerialNumber,
-                      stringsAsFactors = FALSE, NFilePagesSkipped = M$NFilePagesSkipped)
+      filehealth_cols = grep(pattern = "filehealth", x = names(SUMMARY), value = FALSE)
+      if (length(filehealth_cols) > 0) {
+        # migrate filehealth columns to QC report
+        QC = merge(x = QC, y = SUMMARY[, c(which(names(SUMMARY) == "filename"), filehealth_cols)], by = "filename")
+        SUMMARY = SUMMARY[, -filehealth_cols]
+      }
       if (i == 1 | i == f0) {
         QCout = QC
       } else {
@@ -199,9 +194,9 @@ g.report.part2 = function(metadatadir = c(), f0 = c(), f1 = c(), maxdur = 0,
           SUMMARY_clean = tidyup_df(SUMMARY)
           daySUMMARY_clean = tidyup_df(daySUMMARY)
           #store matrix temporarily to keep track of process
-          data.table::fwrite(x = SUMMARY_clean, file = paste0(metadatadir, "/results/part2_summary.csv"), row.names = F, na = "")
-          data.table::fwrite(x = daySUMMARY_clean, file = paste0(metadatadir, "/results/part2_daysummary.csv"), row.names = F, na = "")
-          data.table::fwrite(x = QCout, file = paste0(metadatadir, "/results/QC/data_quality_report.csv"), row.names = F, na = "")
+          data.table::fwrite(x = SUMMARY_clean, file = paste0(metadatadir, "/results/part2_summary.csv"), row.names = F, na = "", sep = sep_reports)
+          data.table::fwrite(x = daySUMMARY_clean, file = paste0(metadatadir, "/results/part2_daysummary.csv"), row.names = F, na = "", sep = sep_reports)
+          data.table::fwrite(x = QCout, file = paste0(metadatadir, "/results/QC/data_quality_report.csv"), row.names = F, na = "", sep = sep_reports)
         }
         pdfpagecount = pdfpagecount + 1
       }
@@ -217,14 +212,14 @@ g.report.part2 = function(metadatadir = c(), f0 = c(), f1 = c(), maxdur = 0,
       
       #===============================================================================
       # store final matrices again
-      data.table::fwrite(x = SUMMARY_clean, file = paste0(metadatadir, "/results/part2_summary.csv"), row.names = F, na = "")
-      data.table::fwrite(x = daySUMMARY_clean, paste0(metadatadir, "/results/part2_daysummary.csv"), row.names = F, na = "")
+      data.table::fwrite(x = SUMMARY_clean, file = paste0(metadatadir, "/results/part2_summary.csv"), row.names = F, na = "", sep = sep_reports)
+      data.table::fwrite(x = daySUMMARY_clean, paste0(metadatadir, "/results/part2_daysummary.csv"), row.names = F, na = "", sep = sep_reports)
       if (store.long == TRUE) { # Convert daySUMMARY to long format if there are multiple segments per day
         df = g.convert.part2.long(daySUMMARY)
         df_clean = tidyup_df(df)
-        data.table::fwrite(x = df_clean, file = paste0(metadatadir, "/results/part2_daysummary_longformat.csv"), row.names = F, na = "")
+        data.table::fwrite(x = df_clean, file = paste0(metadatadir, "/results/part2_daysummary_longformat.csv"), row.names = F, na = "", sep = sep_reports)
       }
-      data.table::fwrite(x = QCout, file = paste0(metadatadir, "/results/QC/data_quality_report.csv"), row.names = F, na = "")
+      data.table::fwrite(x = QCout, file = paste0(metadatadir, "/results/QC/data_quality_report.csv"), row.names = F, na = "", sep = sep_reports)
     }
   }
 }
