@@ -8,7 +8,8 @@ test_that("read.myacc.csv can handle files without header, no decimal places in
   sf = 30
   options(digits.secs = 4)
   t0 = as.POSIXlt(x = "2022-11-02 14:01:16.00", tz = "Europe/Amsterdam")
-  time = as.POSIXlt(t0 + ((0:(N - 1))/sf), origin = "1970-1-1", tz = "Europe/London")
+  timeseq = t0 + ((0:(N - 1))/sf)
+  time = as.POSIXlt(timeseq, origin = "1970-1-1", tz = "Europe/London")
   testfile = matrix("", 4, 1)
   set.seed(100)
   accx = rnorm(N)
@@ -49,14 +50,70 @@ test_that("read.myacc.csv can handle files without header, no decimal places in
                       rmc.col.acc = c(1,3,4), rmc.col.temp = 5, rmc.col.time = 2,
                       rmc.unit.acc = "g", rmc.unit.temp = "C", rmc.format.time = "%Y-%m-%d %H:%M:%OS",
                       rmc.origin = "1970-01-01",
-                      rmc.desiredtz = "Europe/London", rmc.sf = sf,
+                      desiredtz = "Europe/London", rmc.sf = sf,
                       rmc.headername.sf = "sample_frequency",
                       rmc.headername.sn = "serial_number",
                       rmc.headername.recordingid = "ID")
+  
+  #------------------------
+  # Warnings and errors related to desiredtz and configtz
+  # warning if desiredtz not provided but rmc.desiredtz provided:
+  expect_warning(read.myacc.csv(rmc.file = testfile[1], rmc.nrow = 20, rmc.dec = ".",
+                                rmc.firstrow.acc = 1, rmc.firstrow.header = c(),
+                                rmc.col.acc = c(1,3,4), rmc.col.temp = 5, rmc.col.time = 2,
+                                rmc.unit.acc = "g", rmc.unit.temp = "C", 
+                                rmc.format.time = "%Y-%m-%d %H:%M:%OS",
+                                rmc.origin = "1970-01-01",
+                                rmc.desiredtz = "Europe/London", rmc.sf = sf,
+                                rmc.headername.sf = "sample_frequency",
+                                rmc.headername.sn = "serial_number",
+                                rmc.headername.recordingid = "ID"))
+  
+  #  now also with configtz
+  expect_warning(read.myacc.csv(rmc.file = testfile[1], rmc.nrow = 20, rmc.dec = ".",
+                                rmc.firstrow.acc = 1, rmc.firstrow.header = c(),
+                                rmc.col.acc = c(1,3,4), rmc.col.temp = 5, rmc.col.time = 2,
+                                rmc.unit.acc = "g", rmc.unit.temp = "C", 
+                                rmc.format.time = "%Y-%m-%d %H:%M:%OS",
+                                rmc.origin = "1970-01-01",
+                                desiredtz = "Europe/London", 
+                                rmc.configtz = "Europe/Madrid",
+                                rmc.sf = sf,
+                                rmc.headername.sf = "sample_frequency",
+                                rmc.headername.sn = "serial_number",
+                                rmc.headername.recordingid = "ID"))
+  
+  # error if none of rmc.desiredtz and desiredtz are provided:
+  expect_error(read.myacc.csv(rmc.file = testfile[1], rmc.nrow = 20, rmc.dec = ".",
+                              rmc.firstrow.acc = 1, rmc.firstrow.header = c(),
+                              rmc.col.acc = c(1,3,4), rmc.col.temp = 5, rmc.col.time = 2,
+                              rmc.unit.acc = "g", rmc.unit.temp = "C", 
+                              rmc.format.time = "%Y-%m-%d %H:%M:%OS",
+                              rmc.origin = "1970-01-01",
+                              rmc.sf = sf,
+                              rmc.headername.sf = "sample_frequency",
+                              rmc.headername.sn = "serial_number",
+                              rmc.headername.recordingid = "ID"))
+  
+  # error if both rmc.desiredtz and desiredtz are provided:
+  expect_error(read.myacc.csv(rmc.file = testfile[1], rmc.nrow = 20, rmc.dec = ".",
+                              rmc.firstrow.acc = 1, rmc.firstrow.header = c(),
+                              rmc.col.acc = c(1,3,4), rmc.col.temp = 5, rmc.col.time = 2,
+                              rmc.unit.acc = "g", rmc.unit.temp = "C", 
+                              rmc.format.time = "%Y-%m-%d %H:%M:%OS",
+                              rmc.origin = "1970-01-01",
+                              desiredtz = "Europe/London", rmc.desiredtz = "Europe/Madrid",
+                              rmc.sf = sf,
+                              rmc.headername.sf = "sample_frequency",
+                              rmc.headername.sn = "serial_number",
+                              rmc.headername.recordingid = "ID"))
+  
+  
   # Evaluate with decimal places in seconds
   expect_equal(nrow(D1$data), 20)
   expect_equal(ncol(D1$data), 5)
-  expect_equal(as.character(strftime(D1$data$time[1:5], '%Y-%m-%d %H:%M:%OS2')), 
+  expect_equal(strftime(D1$data$time[1:5], format = '%Y-%m-%d %H:%M:%OS2',
+                        tz = "Europe/London"), 
                c("2022-11-02 13:01:16.00",
                  "2022-11-02 13:01:16.03",
                  "2022-11-02 13:01:16.06",
@@ -71,15 +128,15 @@ test_that("read.myacc.csv can handle files without header, no decimal places in
                       rmc.col.acc = c(1,3,4), rmc.col.temp = 5, rmc.col.time = 2,
                       rmc.unit.acc = "g", rmc.unit.temp = "C", rmc.format.time = "%Y-%m-%d %H:%M:%OS",
                       rmc.origin = "1970-01-01",
-                      rmc.desiredtz = "Europe/London", rmc.sf = sf,
-                      rmc.configtz = "America/Chicago",
+                      desiredtz = "Europe/London", rmc.sf = sf,
+                      configtz = "America/Chicago",
                       rmc.headername.sf = "sample_frequency",
                       rmc.headername.sn = "serial_number",
                       rmc.headername.recordingid = "ID")
   expect_equal(nrow(D2$data), 20)
   expect_equal(ncol(D2$data), 5)
-  expect_equal(as.character(strftime(D2$data$time[1:5], 
-                                     '%Y-%m-%d %H:%M:%OS2')),
+  expect_equal(strftime(D2$data$time[1:5], format = '%Y-%m-%d %H:%M:%OS2',
+                        tz = "Europe/London"),
                c("2022-11-02 18:01:16.50", "2022-11-02 18:01:16.53",
                  "2022-11-02 18:01:16.56", "2022-11-02 18:01:16.59",
                  "2022-11-02 18:01:16.63"))
@@ -92,7 +149,7 @@ test_that("read.myacc.csv can handle files without header, no decimal places in
                       rmc.unit.acc = "g", rmc.unit.temp = "C",
                       rmc.format.time = "%Y-%m-%d %H:%M:%OS",
                       rmc.origin = "1970-01-01",
-                      rmc.desiredtz = "Europe/London", 
+                      desiredtz = "Europe/London", 
                       rmc.sf = sf,
                       rmc.headername.sf = "sample_frequency",
                       rmc.headername.sn = "serial_number",
@@ -108,7 +165,7 @@ test_that("read.myacc.csv can handle files without header, no decimal places in
                       rmc.unit.acc = "g", rmc.unit.temp = "C", 
                       rmc.format.time = "%Y-%m-%d %H:%M:%OS",
                       rmc.origin = "1970-01-01",
-                      rmc.desiredtz = "Europe/London", rmc.sf = sf,
+                      desiredtz = "Europe/London", rmc.sf = sf,
                       rmc.headername.sf = "sample_frequency",
                       rmc.headername.sn = "serial_number",
                       rmc.headername.recordingid = "ID",
@@ -133,7 +190,8 @@ test_that("read.myacc.csv can handle header and bit-value acceleration", {
   sf = 30
   options(digits.secs = 4)
   t0 = as.POSIXlt(x = "2022-11-02 14:01:16.00", tz = "Europe/Amsterdam")
-  time = as.POSIXlt(t0 + ((0:(N - 1))/sf), origin = "1970-1-1", tz = "Europe/London")
+  timeseq = t0 + ((0:(N - 1))/sf)
+  time = as.POSIXlt(timeseq, origin = "1970-1-1", tz = "Europe/London")
   testfile = matrix("", 3, 1)
   set.seed(100)
   accx = rnorm(N)
@@ -203,7 +261,7 @@ test_that("read.myacc.csv can handle header and bit-value acceleration", {
                       rmc.unit.acc = "g", rmc.unit.temp = "C",
                       rmc.format.time = "%Y-%m-%d %H:%M:%OS",
                       rmc.origin = "1970-01-01",
-                      rmc.desiredtz = "Europe/London",
+                      desiredtz = "Europe/London",
                       rmc.sf = sf,
                       rmc.headername.sf = "sample_frequency",
                       rmc.headername.sn = "serial_number",
@@ -220,7 +278,7 @@ test_that("read.myacc.csv can handle header and bit-value acceleration", {
                       rmc.unit.acc = "bit", rmc.unit.temp = "C",
                       rmc.format.time = "%Y-%m-%d %H:%M:%OS",
                       rmc.origin = "1970-01-01",
-                      rmc.desiredtz = "Europe/London", rmc.sf = sf,
+                      desiredtz = "Europe/London", rmc.sf = sf,
                       rmc.headername.sf = "sample_rate",
                       rmc.headername.sn = "serial_number",
                       rmc.headername.recordingid = "ID", rmc.bitrate = "bit",
@@ -240,7 +298,7 @@ test_that("read.myacc.csv can handle header and bit-value acceleration", {
                       rmc.unit.acc = "bit", rmc.unit.temp = "C",
                       rmc.format.time = "%Y-%m-%d %H:%M:%OS",
                       rmc.origin = "1970-01-01",
-                      rmc.desiredtz = "Europe/London", rmc.sf = sf,
+                      desiredtz = "Europe/London", rmc.sf = sf,
                       rmc.headername.sf = "sample_rate",
                       rmc.headername.sn = "serial_number",
                       rmc.headername.recordingid = "ID",
@@ -273,7 +331,8 @@ test_that("read.myacc.csv can handle gaps in time and irregular sample rate", {
   sf = 30
   options(digits.secs = 4)
   t0 = as.POSIXlt(x = "2022-11-02 14:01:16.00", tz = "Europe/Amsterdam")
-  time = as.POSIXlt(t0 + ((0:(N - 1))/sf), origin = "1970-1-1", tz = "Europe/London")
+  timeseq = t0 + ((0:(N - 1))/sf)
+  time = as.POSIXlt(timeseq, origin = "1970-1-1", tz = "Europe/London")
   testfile = matrix("", 1, 1)
   set.seed(100)
   accx = rnorm(N)
@@ -312,7 +371,7 @@ test_that("read.myacc.csv can handle gaps in time and irregular sample rate", {
                       rmc.unit.acc = "g", rmc.unit.temp = "C",
                       rmc.format.time = "%Y-%m-%d %H:%M:%OS",
                       rmc.origin = "1970-01-01",
-                      rmc.desiredtz = "Europe/London",
+                      desiredtz = "Europe/London",
                       rmc.sf = sf,
                       rmc.headername.sf = "sample_rate",
                       rmc.headername.sn = "serial_number",
@@ -329,7 +388,7 @@ test_that("read.myacc.csv can handle gaps in time and irregular sample rate", {
                       rmc.unit.acc = "g", rmc.unit.temp = "C",
                       rmc.format.time = "%Y-%m-%d %H:%M:%OS",
                       rmc.origin = "1970-01-01",
-                      rmc.desiredtz = "Europe/London",
+                      desiredtz = "Europe/London",
                       rmc.sf = sf,
                       rmc.headername.sf = "sample_rate",
                       rmc.headername.sn = "serial_number",
